@@ -21,7 +21,7 @@ from .check import (
 )
 
 from .abs_client import AbsMilvus
-from .asynch import SearchFuture, InsertFuture, CreateIndexFuture
+from .asynch import SearchFuture, InsertFuture, CreateIndexFuture, FlushFuture
 
 from .hooks import BaseSearchHook
 from .client_hooks import SearchHook, HybridSearchHook
@@ -603,6 +603,41 @@ class GrpcHandler(AbsMilvus):
 
         return QueryResult(response, auto_id)
 
+    @error_handler(None)
+    def get_query_segment_infos(self, collection_name, timeout=30, **kwargs):
+        req = milvus_types.QuerySegmentInfoRequest(collectionName=collection_name)
+        future = self._stub.GetQuerySegmentInfo.future(req, wait_for_ready=True, timeout=timeout)
+        response = future.result()
+        status = response.status
+        if status.error_code == 0:
+            return response.infos  # todo: A wrapper class of QuerySegmentInfo
+        raise BaseException(status.error_code, status.reason)
+
+    @error_handler()
+    def wait_for_load_index_done(self, collection_name, timeout=30, **kwargs):
+        def load_index_done():
+            query_segment_infos = self.get_query_segment_infos(collection_name)
+            persistent_segment_infos = self.get_persistent_segment_infos(collection_name)
+
+            query_segment_ids = [info.segmentID for info in query_segment_infos]
+            persistent_segment_ids = [info.segmentID for info in persistent_segment_infos]
+            if len(persistent_segment_ids) != len(query_segment_ids):
+                return False
+
+            query_segment_ids.sort()
+            persistent_segment_ids.sort()
+            if query_segment_ids != persistent_segment_ids:
+                return False
+
+            query_segment_index_ids = [info.indexID for info in query_segment_infos]
+            return len(set(query_segment_index_ids)) == 1
+
+        while True:
+            time.sleep(0.5)
+            print("\n***********  waiting for load index done ***********\n")
+            if load_index_done():
+                return
+
     @error_handler()
     def create_index(self, collection_name, field_name, params, timeout=None, **kwargs):
         index_param = Prepare.create_index__request(collection_name, field_name, params)
@@ -617,6 +652,7 @@ class GrpcHandler(AbsMilvus):
         sync = kwargs.get("sync", True)
         if sync:
             self.wait_index_building_success(collection_name=collection_name, field_name=field_name)
+            self.wait_for_load_index_done(collection_name, timeout, kwargs)
         return Status(status.error_code, status.reason)
 
     @error_handler(None)
@@ -659,7 +695,11 @@ class GrpcHandler(AbsMilvus):
     @error_handler()
     def wait_index_building_success(self, collection_name, field_name, timeout=30, **kwargs):
         def index_built():
-            return self.get_index_state(collection_name, field_name) == common_types.IndexState.FINISHED
+            try:
+                return self.get_index_state(collection_name, field_name) == common_types.IndexState.FINISHED
+            except BaseException:
+                return False
+
         while True:
             time.sleep(0.5)
             print("\n***********  waiting for building index ***********\n")
@@ -667,3 +707,99 @@ class GrpcHandler(AbsMilvus):
                 break
 
         return
+
+    @error_handler()
+    def load_collection(self, db_name, collection_name, timeout=None, **kwargs):
+        request = Prepare.load_collection(db_name=db_name, collection_name=collection_name)
+        rf = self._stub.LoadCollection.future(request, wait_for_ready=True, timeout=timeout)
+        response = rf.result()
+        status = response.status
+        if status.error_code == 0:
+            return response.state
+        raise BaseException(status.error_code, status.reason)
+
+    @error_handler()
+    def release_collection(self, db_name, collection_name, timeout=30):
+        request = Prepare.release_collection(db_name=db_name, collection_name=collection_name)
+        rf = self._stub.ReleaseCollection.future(request, wait_for_ready=True, timeout=timeout)
+        response = rf.result()
+        status = response.status
+        if status.error_code == 0:
+            return response.state
+        raise BaseException(status.error_code, status.reason)
+
+    @error_handler
+    def load_partitions(self, db_name, collection_name, partition_names, timeout=30):
+        request = Prepare.load_partitions(db_name=db_name, collection_name=collection_name,
+                                          partition_names=partition_names)
+        rf = self._stub.LoadPartitions.future(request, wait_for_ready=True, timeout=timeout)
+        response = rf.result()
+        status = response.status
+        if status.error_code == 0:
+            return response.state
+        raise BaseException(status.error_code, status.reason)
+
+    @error_handler
+    def release_partitions(self, db_name, collection_name, partition_names, timeout=30):
+        request = Prepare.release_partitions(db_name=db_name, collection_name=collection_name,
+                                             partition_names=partition_names)
+        rf = self._stub.ReleasePartions().future(request, wait_for_ready=True, timeout=timeout)
+        response = rf.result()
+        status = response.status
+        if status.error_code == 0:
+            return response.state
+        raise BaseException(status.error_code, status.reason)
+
+    @error_handler
+    def get_collection_stats(self, collection_name, timeout=None, **kwargs):
+        index_param = Prepare.get_collection_stats_request(collection_name)
+        future = self._stub.GetCollectionStatistics.future(index_param, wait_for_ready=True, timeout=timeout)
+        response = future.result()
+        status = response.status
+        if status.error_code == 0:
+            return response.stats
+
+    @error_handler(None)
+    def get_persistent_segment_infos(self, collection_name, timeout=30, **kwargs):
+        req = milvus_types.PersistentSegmentInfoRequest(collectionName=collection_name)
+        future = self._stub.GetPersistentSegmentInfo.future(req, wait_for_ready=True, timeout=timeout)
+        response = future.result()
+        status = response.status
+        if status.error_code == 0:
+            return response.infos  # todo: A wrapper class of PersistentSegmentInfo
+        raise BaseException(status.error_code, status.reason)
+
+    @error_handler()
+    def wait_for_flushed(self, collection_name, timeout=30, **kwargs):
+        def flushed():
+            try:
+                infos = self.get_persistent_segment_infos(collection_name, timeout, kwargs)
+                for info in infos:
+                    if info.state != common_types.SegmentState.SegmentFlushed:
+                        return False
+                return True
+            except BaseException:
+                return False
+
+        while True:
+            time.sleep(0.5)
+            print("\n***********  waiting for flushed ***********\n")
+            if flushed():
+                return
+
+    @error_handler()
+    def flush(self, collection_name_array: list, timeout=None, **kwargs):
+        print("CZS::::::::::::::::::::::::::::", collection_name_array)
+        request = Prepare.flush_param(collection_name_array)
+        future = self._stub.Flush.future(request, wait_for_ready=True, timeout=timeout)
+        if kwargs.get("_async", False):
+            cb = kwargs.get("_callback", None)
+            return FlushFuture(future, cb)
+        response = future.result()
+        if response.error_code != 0:
+            raise BaseException(response.error_code, response.reason)
+        sync = kwargs.get("sync", True)
+        if sync:
+            for collection_name in collection_name_array:
+                self.wait_for_flushed(collection_name)
+
