@@ -2,6 +2,6 @@
 
 __all__ = [
     'milvus_pb2', 'milvus_pb2_grpc',
-    'common_pb2', 'common_pb2_grpc',
-    'schema_pb2', 'schema_pb2_grpc',
+    'common_pb2',
+    'schema_pb2',
 ]
